##  Aggregation Status
You can view detected software items and their statuses on the Aggregation Status tab of the configuration page. Possible aggregation statuses include:
  * Aggregated: A software installation item is matched and linked to a reference catalog item. Linked fact sheets and providers appear in the corresponding columns. You can navigate to fact sheets from here.
  * In Progress: A software installation item is under review. It's either not recognized or matches multiple items from the reference catalog. The SAP LeanIX team investigates whether this item should be added to the catalog.
  * Rejected: A software installation item is recognized but excluded from aggregation because it's determined to be irrelevant or not actionable.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioe2b7c4ced67249f29ddf51ead4013d35_LowRes.png)
Viewing Detected Software Records
